import { clientFrameworkTypes } from '../../../jdl/index.js';
import { getFrontendAppName } from '../../base/support/basename.mjs';
import { CLIENT_MAIN_SRC_DIR, CLIENT_TEST_SRC_DIR } from '../../generator-constants.mjs';
const { ANGULAR, REACT, VUE, NO: CLIENT_FRAMEWORK_NO } = clientFrameworkTypes;
/**
 * Load client configs into application.
 */
export const loadClientConfig = ({ config, application }) => {
    application.clientPackageManager = config.clientPackageManager;
    application.clientFramework = config.clientFramework;
    application.clientTheme = config.clientTheme;
    application.clientThemeVariant = config.clientThemeVariant;
    application.devServerPort = config.devServerPort;
    application.clientSrcDir = config.clientSrcDir ?? CLIENT_MAIN_SRC_DIR;
    application.clientTestDir = config.clientTestDir ?? CLIENT_TEST_SRC_DIR;
};
/**
 * Load client derived properties.
 */
export const loadDerivedClientConfig = ({ application }) => {
    application.clientFrameworkAngular = application.clientFramework === ANGULAR;
    application.clientFrameworkReact = application.clientFramework === REACT;
    application.clientFrameworkVue = application.clientFramework === VUE;
    application.clientFrameworkNo = !application.clientFramework || application.clientFramework === CLIENT_FRAMEWORK_NO;
    application.clientFrameworkAny = !application.clientFrameworkNo;
    if (application.microfrontend === undefined) {
        if (application.applicationTypeMicroservice) {
            application.microfrontend = application.clientFrameworkAny;
        }
        else if (application.applicationTypeGateway) {
            application.microfrontend = application.microfrontends && application.microfrontends.length > 0;
        }
    }
    application.clientThemeNone = application.clientTheme === 'none';
    application.clientThemePrimary = application.clientThemeVariant === 'primary';
    application.clientThemeLight = application.clientThemeVariant === 'light';
    application.clientThemeDark = application.clientThemeVariant === 'dark';
    if (application.baseName) {
        application.frontendAppName = getFrontendAppName({ baseName: application.baseName });
    }
};
