/**
 * Copyright 2013-2023 the original author or authors from the JHipster project.
 *
 * This file is part of the JHipster project, see https://www.jhipster.tech/
 * for more information.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export default function addJavaAnnotation(content, { package: packageName, annotation }) {
    if (packageName) {
        if (!new RegExp(`import ${packageName.replace('.', '\\.')}.${annotation};`).test(content)) {
            // add the import statement just after the package statement, prettier will arrange it correctly
            content = content.replace(/(package [\w.]+;\n)/, `$1import ${packageName}.${annotation};\n`);
        }
    }
    if (!new RegExp(`\n@${annotation}\n`).test(content)) {
        // add the annotation before class or interface
        content = content.replace(/\n([a-w ]*(class|@?interface|enum) )/g, `\n@${annotation}\n$1`);
    }
    return content;
}
