/**
 * Copyright 2013-2023 the original author or authors from the JHipster project.
 *
 * This file is part of the JHipster project, see https://www.jhipster.tech/
 * for more information.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import JDLEnums from './jdl-enums.js';
import JDLRelationships from './jdl-relationships.js';
import JDLOptions from './jdl-options.js';
import JDLEntity from './jdl-entity.js';
import JDLRelationship from './jdl-relationship.js';
/**
 * The JDL object class, containing applications, entities etc.
 */
export default class JDLObject {
    applications: Record<string, any>;
    deployments: Record<string, any>;
    entities: Record<string, JDLEntity>;
    enums: JDLEnums;
    relationships: JDLRelationships;
    options: JDLOptions;
    constructor();
    getOptions(): any[];
    /**
     * Adds or replaces an application.
     * @param application the application.
     */
    addApplication(application: any): void;
    getApplicationQuantity(): number;
    getApplication(applicationName: any): any;
    getApplications(): any[];
    forEachApplication(passedFunction: any): void;
    /**
     * Adds or replaces a deployment.
     * @param deployment the deployment.
     */
    addDeployment(deployment: any): void;
    getDeploymentQuantity(): number;
    forEachDeployment(passedFunction: any): void;
    /**
     * Adds or replaces an entity.
     * @param entity the entity to add.
     */
    addEntity(entity: JDLEntity): void;
    getEntity(entityName: string): JDLEntity;
    getEntities(): JDLEntity[];
    getEntityQuantity(): number;
    getEntityNames(): string[];
    forEachEntity(passedFunction: (entity: JDLEntity, index: number, entityNames: string[]) => void): void;
    /**
     * Adds or replaces an enum.
     * @param enumToAdd the enum to add.
     */
    addEnum(enumToAdd: any): void;
    hasEnum(enumName: any): boolean;
    getEnum(enumName: any): any;
    getEnumQuantity(): number;
    forEachEnum(passedFunction: any): void;
    addRelationship(relationship: any): void;
    getRelationshipQuantity(applicationName?: string): number;
    forEachRelationship(passedFunction?: (relationship: JDLRelationship) => void): void;
    getRelationships(): JDLRelationship[];
    addOption(option: any): void;
    getOptionsForName(optionName: any): any[];
    forEachOption(passedFunction: any): void;
    hasOption(optionName: any): boolean;
    isEntityInMicroservice(entityName: any): boolean;
    getOptionQuantity(): number;
    toString(): string;
}
